import logging

from flask import current_app as app

from lpreports import db
from lpreports.launchpad import client as lp_client
import lpreports.utils.common

log = logging.getLogger(__name__)


def collect_active_bugs(project):
    lp = lp_client.LaunchpadClient(app.config["LP_CONSUMER_KEY"],
                                   app.config["LP_TOKEN"],
                                   app.config["LP_SIGNATURE"])

    result = []
    start_time = lpreports.utils.common.timestamp_to_utc_date(0)

    for tasks in lp.find_bug_tasks(project, start_time):
        for task in tasks:
            bug_id = task["bug_link"].split("/")[-1]
            if task["milestone_link"]:
                milestone = task["milestone_link"].split("/")[-1]
            else:
                milestone = None

            result.append("{0}-{1}".format(bug_id, milestone))

    lp.close_session()

    return result


def cleanup_db(project, active_tasks):
    for task in db.get_all_bugs_in_project(project):
        query = "{0}-{1}".format(task["id"], task["milestone"])
        if query not in active_tasks:
            log.info("Removing stale bug #{0} from [{1} {2}]".format(
                task["id"], project, task["milestone"]
            ))
            db.delete_bug_task(project, task)


def execute_cleanup():
    log.info("Starting cleanup of stale bugs")

    for project in app.config["PROJECTS_LIST"]:
        log.info("Collecting active bugs in <{0}>".format(project))
        active_tasks = collect_active_bugs(project)
        log.info("Found {0} active tasks in {1}".format(len(active_tasks),
                                                        project))

        cleanup_db(project, active_tasks)

    log.info("Finished cleanup of stale bugs")
