import logging
import sys

import click

from lpreports import application
from lpreports.cmd import cleanup
from lpreports.cmd import collect_assignees
from lpreports.cmd import cve
from lpreports.cmd import lp_credentials
from lpreports.cmd import sync_milestones
from lpreports.cmd import syncdb

log = logging.getLogger(__name__)


@click.group()
def cli():
    pass


@cli.command('generate-lp-credentials')
def generate_lp_credentials():
    lp_credentials.generate_credentials()


@cli.command()
@click.option('--port', type=int, default=1111)
@click.option('--host', default='127.0.0.1')
def devserver(port, host):
    app = application.create_app(enable_logging=False)
    app.run(host=host, port=port)


@cli.command('cleanup-db')
def cleanup_db():
    app = application.create_app(enable_logging=False)
    with app.app_context():
        cleanup.execute_cleanup()


@cli.command('collect-assignees')
def exec_collect_assignees():
    app = application.create_app(enable_logging=False)
    with app.app_context():
        collect_assignees.sync_teams()


@cli.command('syncdb')
@click.option('--drop-db', is_flag=True, default=False)
@click.option('--yes', is_flag=True, default=False)
def exec_syncdb(drop_db, yes):
    prompt_message = "Database will be purged. Do you want to continue?"
    if not yes and drop_db:
        if not click.confirm(prompt_message):
            return
    app = application.create_app(enable_logging=False)
    with app.app_context():
        syncdb.syncdb(drop_db=drop_db)


@cli.command('sync-cve')
def exec_sync_cve():
    app = application.create_app(enable_logging=False)
    with app.app_context():
        cve.update_cves()


@cli.command('sync-milestones')
@click.option('--num-threads', default=5)
def exec_repair_milestones(num_threads):
    app = application.create_app(enable_logging=False)
    with app.app_context():
        sync_milestones.run_sync(num_threads=num_threads)


def main():
    logging_format = "[%(asctime)s] - %(name)s - %(levelname)s - %(message)s"
    logging.basicConfig(stream=sys.stdout,
                        level=logging.DEBUG,
                        format=logging_format)
    logging.getLogger("requests").setLevel(logging.ERROR)
    logging.getLogger("iso8601").setLevel(logging.ERROR)
    cli()


if __name__ == '__main__':
    main()
