import json
import os
import yaml

from lpreports.exceptions import ImproperlyConfigured
from lpreports.util import set_defaults


class Default(object):
    DEBUG = True
    TESTING = False

    SECRET_KEY = "FIXME"

    LP_CONSUMER_KEY = "FIXME"
    LP_TOKEN = "FIXME"
    LP_SIGNATURE = "FIXME"

    GOOGLE_ID = "FIXME"
    GOOGLE_SECRET = "FIXME"

    MONGO_BUGS_DBNAME = 'bugs'
    MONGO_ASSIGNEES_DBNAME = 'assignees'
    MONGO_AREA_TAGS_DBNAME = 'area_tags'
    MONGO_USERS_DBNAME = 'users'
    MONGO_SECURITY_DBNAME = 'security'
    MONGO_CVE_DBNAME = 'cve'

    # Mongo Client doens't work in UWSGI mode, more details can be found on page:
    # http://api.mongodb.com/python/current/faq.html#using-pymongo-with-multiprocessing
    MONGO_BUGS_CONNECT = False
    MONGO_ASSIGNEES_CONNECT = False
    MONGO_AREA_TAGS_CONNECT = False
    MONGO_USERS_CONNECT = False
    MONGO_SECURITY_CONNECT = False
    MONGO_CVE_CONNECT = False

    KEY_MILESTONES = ['9.0']
    PROJECTS_LIST = ['mos', 'fuel', 'fuel-plugins']
    DEFAULT_PROJECTS = ['mos', 'fuel']

    def __init__(self):
        self.CONF_DIRS = None
        self.update_settings('LPREPORTS_CONFDIR', '.:config:/etc/lpreports')
        self.REVIEWS = self.load_config("review.json")
        self.REPORT_CONFIG = self.read_report_config()

    def read_report_config(self):
        config = self.load_config("reports.yaml")
        defaults = config['report-default-values']

        for report in config['reports']:
            set_defaults(report, defaults)

        return config

    def load_config(self, filename):
        for conf_dir in self.CONF_DIRS:
            path = os.path.join(conf_dir, filename)

            if os.path.exists(path):
                with open(path) as f:
                    if path.endswith('json'):
                        return json.load(f)
                    else:
                        return yaml.safe_load(f)

        raise ImproperlyConfigured('%s not found in %r' % (filename, self.CONF_DIRS))

    def update_settings(self, conf_path_envvar, conf_path_default, filename="settings.yaml"):
        conf_path = os.getenv(conf_path_envvar, conf_path_default)
        self.CONF_DIRS = conf_path.split(':')
        self.__dict__.update(self.load_config(filename))


class Testing(Default):
    TESTING = True
    PROPAGATE_EXCEPTIONS = True


class Production(Default):
    pass
