from flask import current_app as app
from lpreports.launchpad import filters


def get_report_by_name(name):
    reports = app.config['REPORT_CONFIG']['reports']
    for report in reports:
        if report['name'] == name:
            return report

    return None


def set_defaults(report, defaults):
    for key in defaults:
        if key not in report:
            report[key] = defaults[key]
        else:
            if isinstance(defaults[key], dict):
                set_defaults(report[key], defaults[key])


def filter_bugs(request, bugs, teams_data):
    default_projects = app.config["DEFAULT_PROJECTS"]

    search_params = {
        'target_name': request.args.getlist('project') or default_projects,
        'milestone': request.args.getlist('milestone'),
        'status': request.args.getlist('status'),
        'importance': request.args.getlist('importance'),
        'reporter': request.args.getlist('reporter'),
        'assignee': request.args.getlist('assignee'),
        'area_tags': request.args.getlist('area_tags'),
        'assigned_person': request.args.getlist('assigned_person'),
        'verifier': request.args.getlist('verifier'),
        'criteria': request.args.getlist('criteria'),
        'tags': request.args.getlist('tags'),
        'tags_all': request.args.getlist('tags_all'),
        'exclude_tags': request.args.getlist('exclude_tags'),
        'exclude_tags_all': request.args.getlist('exclude_tags_all'),
        'component': request.args.getlist('component'),
        'created_from': request.args.get('created_from'),
        'created_to': request.args.get('created_to'),
        'triaged_from': request.args.get('triaged_from'),
        'triaged_to': request.args.get('triaged_to'),
        'fix_committed_from': request.args.get('fix_committed_from'),
        'fix_committed_to': request.args.get('fix_committed_to'),
        'fix_released_from': request.args.get('fix_released_from'),
        'fix_released_to': request.args.get('fix_released_to'),
        'only_user_affecting': bool(request.args.get('only_user_affecting')),
        'teams_and_area_tags': bool(request.args.get('teams_and_area_tags')),
        'original_milestone': request.args.getlist('original_milestone'),
    }

    bugs = filters.filter_bugs(bugs, search_params, teams_data)

    return bugs, search_params
