# I apologize for this code, but it should be merged ASAP
import calendar
import collections
import datetime

import flask
from flask import current_app as app

from lpreports import db

analytics = flask.Blueprint('analytics', __name__)


def match_bug_to_team(bug, major_teams):
    for team, members in major_teams.items():
        if bug.assignee in members:
            return team
    else:
        return "Other"


def get_last_day_of_month(year, month):
    return calendar.monthrange(year, month)[1]


def in_backlog(date_created, date_closed, start_of_month, end_of_month):
    if date_closed is None:
        return True

    created_within_timeframe = (date_created <= end_of_month)
    closed_before_end_of_month = (date_closed <= end_of_month)

    return created_within_timeframe and not closed_before_end_of_month


def calculate_backlog(bugs, teams, year):
    timeseries = collections.OrderedDict()

    end = datetime.datetime.today()
    if end.year != year:
        end = datetime.datetime(year, 12, 31)

    for bug in bugs:
        department = match_bug_to_team(bug, teams)
        date_created = bug.date_created.replace(tzinfo=None)
        dates_closed = [bug.date_closed,
                        bug.date_fix_committed,
                        bug.date_fix_released]

        dates_closed = [d for d in dates_closed if d is not None]

        if len(dates_closed) > 0:
            date_closed = sorted(dates_closed)[0].replace(tzinfo=None)
        else:
            date_closed = None

        for x in range(1, end.month + 1):
            day = get_last_day_of_month(year, x)
            start_of_month = datetime.datetime(year, x, 1).replace(tzinfo=None)
            end_of_month = datetime.datetime(year, x, day).replace(tzinfo=None)

            if in_backlog(date_created, date_closed, start_of_month, end_of_month):
                point = end_of_month
                metrics = timeseries.get(point, dict())
                count = metrics.get(department, 0)
                metrics[department] = count + 1

                total = metrics.get("Total", 0)
                metrics["Total"] = total + 1

                timeseries[point] = metrics

    return timeseries


def get_income_date(bug):
    incoming_dates = [bug.date_confirmed,
                      bug.date_triaged,
                      bug.date_in_progress]

    dates = [d for d in incoming_dates if d is not None]

    if len(dates) > 0:
        return sorted(dates)[0].replace(tzinfo=None)
    else:
        return None


def calculate_incoming(bugs, teams, year):
    timeseries = collections.OrderedDict()

    for bug in bugs:
        department = match_bug_to_team(bug, teams)
        date_created = get_income_date(bug)
        if not date_created:
            continue

        if date_created.year != year:
            continue

        point = date_created.replace(day=1, hour=1,
                                     minute=0, second=0, microsecond=0)

        metrics = timeseries.get(point, dict())
        count = metrics.get(department, 0)
        metrics[department] = count + 1

        total = metrics.get("Total", 0)
        metrics["Total"] = total + 1

        timeseries[point] = metrics

    return collections.OrderedDict(sorted(timeseries.items()))


def rename_key_in_dict(d, oldkey, newkey):
    return collections.OrderedDict((newkey if k == oldkey else k, v)
                                   for k, v in d.viewitems())


def prepare_report(timeseries, teams):
    header = timeseries.keys()
    rows = collections.OrderedDict()

    for point, data in timeseries.items():
        for team in teams:
            count = data.get(team, 0)
            metrics = rows.get(team, [])
            metrics.append(count)
            rows[team] = metrics

    rows = rename_key_in_dict(rows, "MOS OpenStack", "OpenStack")
    rows = rename_key_in_dict(rows, "MOS Linux", "Linux")

    report = {
        "header": header,
        "rows": rows
    }

    return report


@analytics.route("/<int:year>")
def show(year):
    config = app.config['REPORT_CONFIG']['analytics']
    teams = config['teams']

    bugs = []
    for project in config['projects']:
        bugs += db.get_bugs(
            project,
            tags=config['tags-exclude'],
            condition=True,  # exclude bugs with listed tags
        )

    important_bugs = filter(
        lambda bug: bug.importance in config['important-bugs'], bugs)

    major_teams = db.get_major_teams()

    incoming = calculate_incoming(bugs, major_teams, year)
    incoming_important = calculate_incoming(important_bugs, major_teams, year)

    backlog = calculate_backlog(bugs, major_teams, year)
    backlog_important = calculate_backlog(important_bugs, major_teams, year)

    return flask.render_template(
        "analytics.html",
        year=year,
        incoming=prepare_report(incoming, teams),
        incoming_important=prepare_report(incoming_important, teams),
        backlog=prepare_report(backlog, teams),
        backlog_important=prepare_report(backlog_important, teams))
