import datetime

import flask
from flask import current_app as app
from flask import json as flask_json
from flask import Response
import six

from lpreports import db
from lpreports.launchpad import release_chart
from lpreports.launchpad import sla_reports
from lpreports import util
from lpreports.utils import common


charts = flask.Blueprint('charts', __name__)


def _make_product_release_chart(milestone_name):
    criterias = [{'name': 'all', 'implementation': 'criterias.All'}]
    projects = app.config['DEFAULT_PROJECTS']
    milestone_names = [milestone_name]

    app_config = app.config['REPORT_CONFIG']
    options = app_config['report-default-values']['options']

    bugs = sla_reports.get_bugs_by_criteria(criterias, projects,
                                            milestone_names, options=options)

    bugs, filters = util.filter_bugs(flask.request,
                                     {'DATA': [{'bugs': bugs}]},
                                     db.get_full_teams())

    # fake parameters for constructor: we just need to create the
    # chart somehow
    chart = release_chart.ReleaseChart('fuel', milestone_names)
    chart.bugs = bugs['DATA'][0]['bugs']
    initial_date = flask.request.args.get('initial_date')
    chart.initial_date = datetime.datetime.strptime(initial_date, "%Y-%m-%d")
    return chart


@charts.route('/api/bug_trends/<milestone_name>')
def get_bug_trends(milestone_name):
    chart = _make_product_release_chart(milestone_name)
    json = flask_json.dumps(chart.get_trends_data())

    return Response(json, status=200, mimetype='application/json')


@charts.route('/api/incoming_outgoing/<milestone_name>')
@charts.route('/api/incoming_outgoing/<milestone_name>/<tickday>')
def get_incoming_outgoing_data(milestone_name, tickday='monday'):
    try:
        day = common.Weekday.by_name(tickday)
    except ValueError as e:
        # return Bad Request, if an invalid week day name was passed
        return Response(six.text_type(e), status=400, mimetype='text/plain')

    chart = _make_product_release_chart(milestone_name)
    json = flask_json.dumps(chart.get_incoming_outgoing_data(day))

    return Response(json, status=200, mimetype='application/json')


@charts.route('/product/<milestone_name>/')
def show(milestone_name):
    return flask.render_template("bug_charts.html",
                                 project_list=app.config["PROJECTS_LIST"],
                                 milestones=db.get_milestones(),
                                 current_milestone=milestone_name,
                                 teams=db.get_teams())
