import datetime

import flask

from lpreports import db
from lpreports import util


ADVANCED_FILTERS = [
    'assigned_person', 'reporter', 'verifier', 'exclude_tags',
    'created_from', 'triaged_from',
    'fix_committed_from', 'fix_released_from', 'created_to', 'triaged_to',
    'fix_committed_to', 'fix_released_to']


def _is_advanced_filter_set(filters):
    for filter_name in ADVANCED_FILTERS:
        if filters[filter_name]:
            return True

    return False


def _print_select(dct, param, val):
    if param not in dct or val not in dct[param]:
        return ""
    return "selected=\"selected\""


def _get_report_url(submenu, milestone):
    report = util.get_report_by_name(submenu['report-name'])
    report_params = []

    if report['parameter'] == 'milestone':
        if report['name'] == 'maintenance_report':
            milestone = db.get_maintenance_milestones()
        milestone = 'milestone={0}'.format('&milestone='.join(map(str, milestone)))
        report_params.append(milestone)

    if 'additional-params' in submenu:
        report_params.append(submenu['additional-params'])

    url = flask.url_for('reports.show', report_name=submenu['report-name'])

    if report_params:
        url += '?' + '&'.join(report_params)

    return url


def _get_report_title(submenu):
    if 'text' in submenu:
        return submenu['text']
    else:
        report = util.get_report_by_name(submenu['report-name'])
        return report['text']


def register_jinja_globals(_app, app_config, reviews, key_milestones):
    _app.jinja_env.globals.update(
        print_select=_print_select,
        is_advanced_filter_set=_is_advanced_filter_set,
        get_report_url=_get_report_url,
        get_report_title=_get_report_title,
        datetime=datetime,
        app_config=app_config,
        key_milestones=key_milestones,
        get_update_timestamp=db.get_update_timestamp,
        review=reviews)
