function render_bug_trends(container_id, data_url) {
    d3.json(data_url, function(data) {
        nv.addGraph(function() {
          var chart = nv.models.stackedAreaChart()
            .x(function(d) { return d[0] })
            .y(function(d) { return d[1] })
            .color(function(d) {
              colors = {
                "Open": "#FEA455", // dark orange
                "Incomplete": "#E16767", // dark red
                "Resolved": "#B6E7AC", // light green
                "Verified": "#6ABB6A", // dark green
                "In Progress": "#619FC9" // dark blue
              };
              return colors[d["key"]];
            })
            .clipEdge(true)
            .useInteractiveGuideline(true)
            .showControls(false)
            .forceY([0, 0])
            .noData("No issues were found to match your search.");

          chart.xAxis
              .showMaxMin(true)
              .axisLabel('Date')
              .tickFormat(function(d) { return d3.time.format('%x')(new Date(d)) });

          chart.yAxis
              .showMaxMin(true)
              .axisLabel('# of bugs')
              .tickFormat(d3.format(',.0f'));

          d3.select('#' + container_id + ' svg')
              .datum(data)
              .transition().duration(500).call(chart);

          nv.utils.windowResize(chart.update);

          $('#' + container_id + ' img').hide();

          return chart;
        });
    });
}

function render_in_out_bugs(container_id, data_url) {
  d3.json(data_url, function(data) {
    nv.addGraph(function() {
        var chart = nv.models.multiBarChart()
          .x(function(d) { return d[0] })
          .y(function(d) { return d[1] })
          .color(function(d) {
            colors = {
              "Incoming": "#E16767", // dark red
              "Outgoing": "#B6E7AC"  // light green
            };
            return colors[d["key"]];
          })
          .showControls(true)   //Allow user to switch between 'Grouped' and 'Stacked' mode.
          .groupSpacing(0.1)    //Distance between each group of bars.
          .showControls(false)
          .noData("No issues were found to match your search.");

        chart.xAxis
          .showMaxMin(true)
          .axisLabel('Date')
          .tickFormat(function(d) { return d3.time.format('%x')(new Date(d)) });

        chart.yAxis
          .showMaxMin(true)
          .axisLabel('# of bugs')
          .tickFormat(d3.format(',.0f'));

       d3.select('#' + container_id + ' svg')
          .datum(data)
          .transition().duration(500).call(chart);

      nv.utils.windowResize(chart.update);

      $('#' + container_id + ' img').hide();

      return chart;
    });
  });
}

function render_burndown_chart(container_id, data_url) {
    d3.json(data_url, function(data) {
        var incomplete_arr = null;
        var open_arr = null;
        var in_progress_arr = null;
        var unresolved = [];

        for (var i = 0; i < data.length; i++) {
            if (data[i]["key"] == "Incomplete") {
                incomplete_arr = data[i]["values"];
            }
            if (data[i]["key"] == "Open") {
                open_arr = data[i]["values"];
            }
            if (data[i]["key"] == "In Progress") {
                in_progress_arr = data[i]["values"];
            }
        }

        for (var i = 0; i < open_arr.length; i++) {
            var sum = incomplete_arr[i][1] + open_arr[i][1] + in_progress_arr[i][1];
            unresolved.push([open_arr[i][0], sum]);
        }

        if (!unresolved.length) {
            return null;
        }

        var last = unresolved.length - 1;

        var guildeline_end = Date.parse($("#guideline_final").val());

        var guideline = [[unresolved[0][0], unresolved[0][1]],
            [guildeline_end, 0]];

        var burndown = [{"key": "Unresolved", "values": unresolved, "area": true},
            {"key": "Guideline", "values": guideline}];

        nv.addGraph(function () {
            var chart = nv.models.lineChart()
                .x(function (d) {
                       return d[0]
                   })
                .y(function (d) {
                       return d[1]
                   })
                .color(function (d) {
                           colors = {
                            "Unresolved": "#B6E7AC", // light green
                            "Guideline": "#E16767"
                           };
                           return colors[d["key"]];
                       })
                .clipEdge(true)
                .margin({left: 75})
                .useInteractiveGuideline(true)
                .forceY([0, 0])
                .noData("No issues were found to match your search.");

            chart.xAxis
                .showMaxMin(true)
                .axisLabel('Date')
                .tickFormat(function (d) {
                                return d3.time.format('%x')(new Date(d))
                            });

            chart.yAxis
                .showMaxMin(true)
                .axisLabel('# of bugs')
                .tickFormat(d3.format(',.0f'));

            d3.select('#' + container_id + ' svg')
                .datum(burndown)
                .transition().duration(500).call(chart);

            nv.utils.windowResize(chart.update);

            $('#' + container_id + ' img').hide();

            return chart;
        });
    });
}
