var multiselects = ['target_name_select', 'milestone_select', 'status_select', 'importance_select',
    'assignee_select', 'reporter_select', 'verifier_select', 'component_select', 'area_tags_select',
    'original_milestone_select',];
var datepickers = ['date_created', 'date_fix_committed', 'date_fix_released', 'dates_range_filter'];
var switchers = ['tags_switch', 'exclude_tags_switch', 'teams_and_area_tags_switch'];

function text_to_query_str(text_input_name, param_name) {
    if ($(text_input_name).val() == "") {
        return "";
    }

    var items = $(text_input_name).val().split(" ");

    return items.map(function(item) {
        if (item == "") {
            return "";
        }
        if ($("#" + param_name + "_switch").is(":checked")) {
            param_name += "_all";
        }
        return "&" + param_name + "=" + item;
    }).join("");
}

function create_people_filters() {
    var query_str = "";

    $("#assignee_select option:selected").each(function() {
        query_str += "&assignee=" + $(this).text();
    });

    $( "#area_tags_select option:selected" ).each(function() {
         query_str += "&area_tags=" + $(this).text();
    });

    $( "#reporter_select option:selected" ).each(function() {
         query_str += "&reporter=" + $(this).text();
    });

    $("#verifier_select option:selected").each(function() {
        query_str += "&verifier=" + $(this).text();
    });

    query_str += text_to_query_str("#assigned_person_select", "assigned_person");

    return query_str;
}

function go_to_url(base_url, assignee_str, tab_name) {
    var query_str = "";

    $("#target_name_select option:selected").each(function() {
        query_str += "&project=" + $(this).text();
    });

    $("#milestone_select option:selected").each(function() {
        query_str += "&milestone=" + $(this).text();
    });

    $("#original_milestone_select option:selected").each(function() {
        query_str += "&original_milestone=" + $(this).text();
    });

    $("#status_select option:selected").each(function() {
        query_str += "&status=" + $(this).text();
    });

    $("#importance_select option:selected").each(function() {
        query_str += "&importance=" + $(this).text();
    });

    $( "#component_select option:selected" ).each(function() {
        query_str += "&component=" + $(this).text();
    });

    query_str += text_to_query_str("#tags_select", "tags");

    query_str += text_to_query_str("#exclude_tags_select", "exclude_tags");

    if ($("#teams_and_area_tags_switch").is(":checked")){
        query_str += "&teams_and_area_tags=true"
    }
    if($("#user_affecting").is(":checked")){
        query_str += "&only_user_affecting=true";
    }

    var status = ["created", "fix_committed", "fix_released"];
    var border = ["_from", "_to"];

    var dates_filter = "";
    for (var i = 0; i < status.length; i++) {
        for (var j = 0; j < border.length; j++) {
            var dt = $("#date_" + status[i] + border[j]).val();
            if (dt != "") {
                dates_filter += "&" + status[i] + border[j] + "=" + dt;
            }
        }
    }

    query_str += dates_filter;
    query_str += assignee_str;

    if (tab_name != "") {
        query_str += "&tab_name=" + tab_name;
    }

    query_str = query_str.substr(1, query_str.length);

    window.location.href = base_url + "?" + query_str;
}

function get_current_url() {
    var current_url = document.URL;
    if (current_url.indexOf("?") > -1) {
        current_url = current_url.substr(0, current_url.indexOf("?"));
    }
    return current_url
}

function apply_filters() {
    go_to_url(get_current_url(), create_people_filters(), "");
}

function get_csv() {
    var query_str = "&format=csv" + create_people_filters();

    go_to_url(get_current_url(), query_str, "");
}

function bind_search_key() {
    var search_btn = $('.searchform #apply-filters');

    if (!search_btn.length) {
        return false;
    }

    $('body').keypress(function(e) {
        var key = e.which;
        if (key === 13) {  //enter key code
            search_btn.click();
            return false;
        }
    });
}

function bind_component_select() {
    $('#component_select').change(function() {
        var tags = $(this).val() || [];
        $('#tags_switch').bootstrapSwitch('state', false);
        $('#tags_select').val(tags.join(' '));
    });
}

function reset_search_form() {
    multiselects.forEach(function(i) {
       $('#'+i).multipleSelect('uncheckAll');
    });

    $('#target_name_select').val("");
    $('#milestone_select').val("");
    $('#status_select').val("");
    $('#importance_select').val("");
    $('#assignee_select').val("");
    $('#criteria_select').val("");
    $('#tags_select').val("");
    $('#exclude_tags_select').val("");
    $('#component_select').val("");

    datepickers.forEach(function(i) {
        $('#' + i + '_from').datepicker('setDate', null);
        $('#' + i + '_to').datepicker('setDate', null);
    });

    switchers.forEach(function(i) {
        $('#' + i).bootstrapSwitch('state', false);
    });
}

$(document).ready(function() {
    enableMultiselects(multiselects);
    enableDatePickers(datepickers);
    enableSwitchers(switchers);
    bind_search_key();
    bind_component_select();

    addToolTip('tags_select', 'List of tags separated by space.<br><br>' +
            'You can use a logical conjunction (AND) or disjunction (OR) for searching for multiple tags.');
    addToolTip('exclude_tags_select', 'List of excluded tags separated by space.<br><br>' +
            'You can use a logical conjunction (AND) or disjunction (OR) for searching for multiple tags.');
    addToolTip('assigned_person_select', 'List of launchpad IDs separated by space.');

    addToolTip('btn_reset', 'Reset input form');
    addToolTip('btn_csv', 'Get CSV');
});
